@@ -3,15 +3,15 @@ TOMCAT_DST_FOLDER="tomcat"
 TOMCAT_VERSION="8.5.47"
 TOMCAT_PID_FILENAME="tomcat.pid"
 SMARTGEAR_DISTRIBUTION_DIRECTORY=$(ls -d smartgears-distribution-*)
-SMARTGEAR_ROOT=/var/lib/jenkins
+SMARTGEAR_ROOT=${PWD}
 
 BUNDLE_HOME=${SMARTGEAR_ROOT}
 STARTUP_SCRIPT="startContainer.sh"
 STOP_SCRIPT="stopContainer.sh"
 
 GHN_HOME=${SMARTGEAR_ROOT}/SmartGears
-CONTAINER_FILENAME="container.xml"
-CONTAINER_XML=${GHN_HOME}/${CONTAINER_FILENAME}
+CONTAINER_FILENAME="container.ini"
+CONTAINER_INI=${GHN_HOME}/${CONTAINER_FILENAME}
 
 CATALINA_OPTS_BASHRC="export CATALINA_OPTS=\"-Xmx2000m -Xms2000m\""
 GHN_HOME_BASHRC="export GHN_HOME=${GHN_HOME}"
@@ -37,19 +37,18 @@ function hostname {
 	
 	while [ "$HOST_OK" = false ]
 	do
-		
 		echo "Is ${HOST} correct?"
 		select yn in "Yes" "No";
 		do
-		    case $yn in
-		        Yes )
-		        	ok=true
-		        	HOST_OK=true;
-		        	break;;
-		        No )
-		        	ok=false
-		        	break;;
-		    esac
+			case $yn in
+				Yes )
+					ok=true
+					HOST_OK=true;
+					break;;
+				No )
+					ok=false
+					break;;
+			esac
 		done
 		
 		if [ "$ok" = false ]; then
@@ -60,29 +59,29 @@ function hostname {
 }
 
 function escape_slashes {
-    sed 's/\//\\\//g' 
+	sed 's/\//\\\//g' 
 }
 
 function change_line {
-    local OLD_LINE_PATTERN=$1; shift
-    local NEW_LINE=$1; shift
-    local FILE=$1
+	local OLD_LINE_PATTERN=$1; shift
+	local NEW_LINE=$1; shift
+	local FILE=$1
 
-    local NEW=$(echo "${NEW_LINE}" | escape_slashes)
-    sed -i '/'"${OLD_LINE_PATTERN}"'/s/.*/'"${NEW}"'/' "${FILE}"
+	local NEW=$(echo "${NEW_LINE}" | escape_slashes)
+	sed -i '/'"${OLD_LINE_PATTERN}"'/s/.*/'"${NEW}"'/' "${FILE}"
 }
 
 while getopts ":n:fh" opt; do
 	case $opt in
 		n) HOST=$OPTARG;;
 		f) force=true;;
-    	h) showhelp
+		h) showhelp
 			exit 0 ;;
 		\?) echo -e "\nERROR:invalid option: -$OPTARG"; 
 			showhelp; 
 			echo -e "\naborting.\n" 
 			exit 1 >&2 ;;
-  	esac
+	esac
 done
 
 if [ $force ]; then
@@ -129,7 +128,7 @@ if [ $force ]; then
 	./install -s tomcat -g ${GHN_HOME}
 	
 	hostname
-	change_line "<hostname>" "\t<hostname>$HOST</hostname>" ${CONTAINER_XML}
+	change_line "hostname = localhost" "hostname = $HOST" ${CONTAINER_INI}
 	
 	echo -e "\n\n\n"
 	echo "Just few steps to do to reach the goal:"
@@ -180,14 +179,14 @@ else
 	
 	echo "Then:"
 	
-	echo "- Modify ${CONTAINER_XML} with your hostname"
+	echo "- Modify ${CONTAINER_INI} with your hostname"
 fi
 
-echo "- Modify ${CONTAINER_XML} startup infrastructure and vres"
+echo "- Modify ${CONTAINER_INI} authorization section"
 
 echo "- You can Start the container from ${BUNDLE_HOME} directory using the command ./${STARTUP_SCRIPT}"
 echo "- You can Stop the container from ${BUNDLE_HOME} directory using the command ./${STOP_SCRIPT}"
 
 echo ""
 echo "PLEASE NOTE:"
-echo "By default Tomcat start on 8080 port. If you want to change this port REMEMBER to modify ${CONTAINER_XML} consistently"
\ No newline at end of file
+echo "By default Tomcat start on 8080 port. If you want to change this port REMEMBER to modify ${CONTAINER_INI} consistently"
\ No newline at end of file
